#ifndef _NVMC_CIRCUIT_
#define _NVMC_CIRCUIT_
/****************************************************************************
* NVMC                                                                      *
* EnVy My Car																*
*                                                                           *
* Fabio Ganovelli                                                           *
*                                                                           *
* All rights reserved.                                                      *
*                                                                           *
* This program is free software; you can redistribute it and/or modify      *
* it under the terms of the GNU General Public License as published by      *
* the Free Software Foundation; either version 2 of the License, or         *
* (at your option) any later version.                                       *
*                                                                           *
* This program is distributed in the hope that it will be useful,           *
* but WITHOUT ANY WARRANTY; without even the implied warranty of            *
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
* GNU General Public License (http://www.gnu.org/licenses/gpl.txt)          *
* for more details.                                                         *
*                                                                           *
****************************************************************************/



#include <vector>
#include <vcg/space/box3.h>
#include "street.h"

/** A Circuit is a street, a number of entry points and the bounding box. 
In the final version the circuit will entirely describe the place where the race is taking place,
therefore this class is bound to be reatly extended.
*/
class Circuit{

public:
	/** the street	*/
	Street street;

	/** the bounding box of the whole circuit */
	vcg:: Box3f bbox;

	/** The position  of the sun */
	vcg::Point4f sun_position;

	/** A Building is stored as its footprint and its height 
	*/
	struct Building{
		std::vector<Vertex> footprint;
		float height;
	};

	/** buildings: a vector containing all the buildings */
	std::vector<Building> buildings;

	/** BuildingsIterator an iterator over the buildings */
	typedef std::vector<Building>::iterator BuildingsIterator;

	/** A Tree is stored as its position and  its height 
	*/
	struct Tree{
		vcg::Point3f pos;
		float height;
	};

	/** trees: a vector containing all the trees */
	std::vector<Tree> trees;

	/** TreesIterator an iterator over the trees */
	typedef std::vector<Tree>::iterator TreesIterator;

	/** Save the circuit */
	void Save(char * filename);

	/** Load the circuit */
	void Load(char * filename);
};

#endif
