#ifndef _NVMC_SCREENSHOT_
#define _NVMC_SCREENSHOT_
/****************************************************************************
* NVMC                                                                      *
* EnVy My Car																*
*                                                                           *
* Fabio Ganovelli                                                           *
*                                                                           *
* All rights reserved.                                                      *
*                                                                           *
* This program is free software; you can redistribute it and/or modify      *
* it under the terms of the GNU General Public License as published by      *
* the Free Software Foundation; either version 2 of the License, or         *
* (at your option) any later version.                                       *
*                                                                           *
* This program is distributed in the hope that it will be useful,           *
* but WITHOUT ANY WARRANTY; without even the implied warranty of            *
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
* GNU General Public License (http://www.gnu.org/licenses/gpl.txt)          *
* for more details.                                                         *
*                                                                           *
****************************************************************************/


#include <QMutex>
#include <GL/glew.h>


/** a screenshot is a image (here defined as a raw R8B8G8 image */
struct Screenshot{
	Screenshot ( ):w(0),h(0),pixels(0),textureIDAssigned(false),textureUpToDate(false) { mutex_on_this = new QMutex();}

	void Init(const int &_w,const int & _h){
		if( (_w!=w) || (_h!=h)) {
                        if(pixels!=0) delete [] (char*)pixels;
			w=_w;
			h=_h;
                        pixels = new char[h*w*3];
		}
	}

	/** set an image as screenshot */
	void Set(const int &_w,const int & _h,void * _p){
		if(  (_w!=w) || (_h!=h)) 
			Init(_w,_h); 
		memcpy(pixels,_p,h*w*3);
	}

	/** return the pointer to the memory address of  the screenshot */
	void * SetPtr(const int &_w,const int & _h){
		if(!pixels || (_w!=w) || (_h!=h)) 
			Init(_w,_h); 
		return  pixels;
	}

	/** size of the screenshot **/
	int w,h;

	/** pixels **/
	void * pixels;

	/** texture number is assigned **/
	bool textureIDAssigned; 

	/** textureID **/
	GLuint textureID;

	/** content updated **/
	bool textureUpToDate;

	/** muxte on the screenshot **/
	QMutex  * mutex_on_this;

};
#endif
